@@ -480,8 +480,8 @@ class tree:
         surfs = []
         t_list = np.linspace(0,1,num=1000)
         for vessel_id in range(len(interp_xyz)):
-            x,y,z,r = splev(t_list,interp_xyzr[vessel_id][0])
-            #_,r = splev(t_list,interp_r[vessel_id][0])
+            x,y,z = splev(t_list,interp_xyz[vessel_id][0])
+            _,r = splev(t_list,interp_r[vessel_id][0])
             points = np.zeros((len(t_list),3))
             points[:,0] = x
             points[:,1] = y
